package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````R"(```````!``````````)"A````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````"B:````````*)H`````````
M``$```````$````&````0)L```````!`FP$``````$";`0``````0`4`````
M``!H%0```````````0```````@````8```!0FP```````%";`0``````4)L!
M```````@`@```````"`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````3)(```````!,D@```````$R2````````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````$";````````0)L!``````!`FP$`
M`````,`$````````P`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`CPVJPBX])AL<XIL^22+J2,D!
M$D0$````$`````$```!'3E4```````,````'`````````!$```!.````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(H!!%N@`""$X```!/````
M4@```%8```!7````7P```&````!A````8P```&0```!F````9P```&@```!I
M````;````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_
MY`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/NA;&!K"4/69Z_,
M9D)%U>R)!W#3#13BGC)BV^W;S>.>%8PES`TZEPM_J9R;X*<""FH:GE"_VE<;
MH^#[20`````````````````````````````````````#``L`>!P`````````
M```````````````#`!8``*`!``````````````````P!```2````````````
M`````````````#P"```2`````````````````````````),````2````````
M``````````````````$!```1`````````````````````````"D#```2````
M`````````````````````),!```2``````````````````````````,"```2
M`````````````````````````&P"```2`````````````````````````"(!
M```2`````````````````````````"T````@````````````````````````
M`-P"```2`````````````````````````%X"```2````````````````````
M``````\$```2`````````````````````````%,!```2````````````````
M`````````&T#```1`````````````````````````+0````2````````````
M`````````````$,!```2`````````````````````````)P"```2````````
M`````````````````#4!```2`````````````````````````$D"```2````
M`````````````````````!4"```2`````````````````````````.P"```2
M`````````````````````````/8"```B`````````````````````````!$`
M```@`````````````````````````($"```2````````````````````````
M`+$!```2`````````````````````````#P````@````````````````````
M`````"("```2`````````````````````````!H"```2````````````````
M`````````!L#```2`````````````````````````,X"```1````````````
M`````````````%$"```2`````````````````````````%8````2````````
M`````````````````(,!```2`````````````````````````',````2````
M`````````````````````(@"```2`````````````````````````/`````2
M`````````````````````````(0````2`````````````````````````-4"
M```2`````````````````````````,P!```2````````````````````````
M`$4#```2`````````````````````````/X!```2````````````````````
M`````(X"```2`````````````````````````+$"```2````````````````
M`````````-0````2`````````````````````````"L"```2````````````
M`````````````'4!```2`````````````````````````,0"```2````````
M`````````````````&<!```2`````````````````````````*H!```2````
M`````````````````````!8!```2`````````````````````````"(#```2
M`````````````````````````*,"```2`````````````````````````+P"
M```2`````````````````````````&4"```2````````````````````````
M`)\````2`````````````````````````.4"```2````````````````````
M`````)X!```2`````````````````````````$,"```2````````````````
M`````````%<"```2`````````````````````````.,````1````````````
M`````````````!$!```2`````````````````````````.,!```2````````
M`````````````````%P!```2`````````````````````````&0````2````
M`````````````````````!,#```2`````````````````````````-T!```2
M`````````````````````````#L#```1`````````````````````````/<!
M```2`````````````````````````#P#```A````````````````````````
M`',"```2``````````````````````````4#```2````````````````````
M`````#T#```1`````````````````````````'H"```2````````````````
M`````````,(````2`````````````````````````'H$```0`!<`J+`!````
M`````````````!@$```2``T`Z#T```````"``````````)\$```2``T`,#,`
M``````"D!@```````#8#```2``T`H"`````````H`@```````'\#```2``T`
M:"P````````$`````````*T#```2``T`V#D````````,!````````$`$```0
M`!<`@*`!`````````````````,4$```2``T`<"P````````8`@```````(4$
M```0`!<`@*`!`````````````````)`#```2``T`B"X````````H````````
M`,,#```2``T`F#$```````"(`````````"0$```1``\`V%,````````$````
M`````$X$```2``T`@%`````````8`0```````%D$```2``T``"L````````X
M`````````&$$```0`!<`J+`!`````````````````)H$```0`!<`J+`!````
M`````````````+,$```2``T`0#(```````#L`````````#,$```0`!8``*`!
M`````````````````.<#```2``T`L"X````````8`0```````*P$```0`!8`
M@*`!`````````````````-($```1`!8`>*`!```````(`````````)T#```2
M``T`L%,````````$`````````#D$```2``T`R"(``````````````````&D$
M```2``T`,%,```````!\`````````)$$```2``T`*%````````!4````````
M`#4$```@`!8``*`!`````````````````/T#```2``T`(#(````````@````
M`````-$#```2``T`D"L```````#8`````````/,#```2``T`F%$```````"4
M`0```````'D$```0`!<`J+`!`````````````````-P$```2``T`R"\`````
M``#,`0````````!L:6)P97)L+G-O+C4N,S``7TE435]D97)E9VES=&5R5$U#
M;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R
M;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?
M=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`&QI8G!T:')E860N<V\N,`!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`'!T
M:')E861?9V5T<W!E8VEF:6,`;W!E;C8T`')E860`;'-E96LV-`!L:6)C+G-O
M+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL
M:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I9`!S=')D=7``
M<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C
M:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?
M>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER
M-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S
M<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T
M97)?871F;W)K`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K7V-H:U]G
M=6%R9`!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U
M7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?
M=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS
M7VEN:70`7U]E;F1?7P!?7VQI8F-?8W-U7VEN:70`7U]B<W-?96YD7U\`7U]B
M<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A
M<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN
M:71?96YV`$=,24)#7S(N,3<````````````"```````"`````P`"```````"
M``(``@````0```````(````"``(``@`"`````@```````@`"``(``@`"````
M``````(```````(``P`"``,``@`"`````@````(````"`````@`"``(``@``
M``(````"``(````"``,```````(``P`"``,``@`"``(``@`"`````0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0````$``0!7`P``$````"````"7D98&```$`.D$````````
M`0`!`+P!```0````(````)>1E@8```,`Z00````````!``$`"P(``!``````
M````EY&6!@```@#I!````````$";`0```````P0```````#0(P```````$B;
M`0```````P0```````"((P```````(B?`0```````P0```````"P4P``````
M`."?`0```````P0````````P4P```````/B?`0```````P0```````"@(```
M``````B@`0```````P0````````(H`$``````!B@`0```````P0```````#@
M4P```````""@`0```````P0```````#H4P```````#"@`0```````P0`````
M``#P4P```````#B@`0```````P0`````````5````````$"@`0```````P0`
M```````(5````````$B@`0```````P0````````05````````%"@`0``````
M`P0````````85````````&"@`0```````P0````````@5````````&B@`0``
M`````P0````````H5````````'B@`0```````P0```````"P5P```````)"?
M`0```````00```8``````````````)B?`0```````00```L`````````````
M`*"?`0```````00```P``````````````*B?`0```````00``!$`````````
M`````+"?`0```````00``!D``````````````+B?`0```````00``!H`````
M`````````,"?`0```````00``!T``````````````,B?`0```````00``"$`
M`````````````-"?`0```````00``"0``````````````-B?`0```````00`
M`"4``````````````.B?`0```````00``#\``````````````/"?`0``````
M`00``$L``````````````(B=`0```````@0```,``````````````)"=`0``
M`````@0```0``````````````)B=`0```````@0```4``````````````*"=
M`0```````@0```<``````````````*B=`0```````@0```@`````````````
M`+"=`0```````@0```D``````````````+B=`0```````@0```H`````````
M`````,"=`0```````@0```P``````````````,B=`0```````@0```T`````
M`````````-"=`0```````@0```X``````````````-B=`0```````@0```\`
M`````````````."=`0```````@0``!```````````````.B=`0```````@0`
M`!(``````````````/"=`0```````@0``!,``````````````/B=`0``````
M`@0``!0```````````````">`0```````@0``!4```````````````B>`0``
M`````@0``!8``````````````!">`0```````@0``!<``````````````!B>
M`0```````@0``!@``````````````"">`0```````@0``!D`````````````
M`"B>`0```````@0``!L``````````````#">`0```````@0``!P`````````
M`````#B>`0```````@0``!X``````````````$">`0```````@0``!\`````
M`````````$B>`0```````@0``"```````````````%">`0```````@0``"(`
M`````````````%B>`0```````@0``",``````````````&">`0```````@0`
M`"8``````````````&B>`0```````@0``"<``````````````'">`0``````
M`@0``"@``````````````'B>`0```````@0``"D``````````````(">`0``
M`````@0``"H``````````````(B>`0```````@0``"L``````````````)">
M`0```````@0``"P``````````````)B>`0```````@0``"T`````````````
M`*">`0```````@0``"X``````````````*B>`0```````@0``"\`````````
M`````+">`0```````@0``#```````````````+B>`0```````@0``#$`````
M`````````,">`0```````@0``#(``````````````,B>`0```````@0``#,`
M`````````````-">`0```````@0``#0``````````````-B>`0```````@0`
M`#4``````````````.">`0```````@0``#8``````````````.B>`0``````
M`@0``#<``````````````/">`0```````@0``#@``````````````/B>`0``
M`````@0``#D```````````````"?`0```````@0``#H```````````````B?
M`0```````@0``#L``````````````!"?`0```````@0``#P`````````````
M`!B?`0```````@0``#T``````````````""?`0```````@0``#X`````````
M`````"B?`0```````@0``$```````````````#"?`0```````@0``$$`````
M`````````#B?`0```````@0``$(``````````````$"?`0```````@0``$,`
M`````````````$B?`0```````@0``$0``````````````%"?`0```````@0`
M`$4``````````````%B?`0```````@0``$<``````````````&"?`0``````
M`@0``$D``````````````&B?`0```````@0``$H``````````````'"?`0``
M`````@0``$P``````````````'B?`0```````@0``$T``````````````/U[
MOZG]`P"1H`$`E/U[P:C``U_6`````/![OZG0``"0$<)&^1`"-I$@`A_6'R`#
MU1\@`]4?(`/5T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(VD2`"'];0``"0
M$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y$*(VD2`"'];0
M``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1XD;Y$`(WD2`"
M'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM```)`1[D;Y$&(W
MD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?UM```)`1^D;Y
M$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1(`(?UM```)`1
M!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D08CB1(`(?UM``
M`)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:1_D0PCB1(`(?
MUM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```D!$F1_D0(CF1
M(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6T```D!$R1_D0
M@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@`A_6T```D!$^
M1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B.I$@`A_6T```
MD!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'^1"".I$@`A_6
MT```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0$5Y'^1#B.I$@
M`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0``"0$6I'^1!"
M.Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"'];0``"0$79'
M^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([D2`"'];0``"0
M$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y$$(\D2`"'];0
M``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1ED?Y$*(\D2`"
M']:P``#P$9I'^1#"/)$@`A_6L```\!&>1_D0XCR1(`(?UK```/`1HD?Y$`(]
MD2`"']:P``#P$:9'^1`B/9$@`A_6L```\!&J1_D00CV1(`(?UK```/`1KD?Y
M$&(]D2`"']:P``#P$;)'^1""/9$@`A_6L```\!&V1_D0HCV1(`(?UK```/`1
MND?Y$,(]D2`"']:P``#P$;Y'^1#B/9$@`A_6_7NYJ?T#`)'S4P&IM```\(/6
M1_GU6P*I]QL`^>*'!*GB(P&19`!`^>0W`/D$`(#2X4,!D>!?`+G@<P&1T?__
MEZ```/"B``#P`.Q'^4+,1_GA`P*JL0P`E*```/``]$?Y``!`.4`*`#33``"0
MM0``\+7*1_F@`D"YNO__EP)H4CE"`!\R`F@2.:`"0+FU__^7`FA2.4(``#("
M:!(YX%]`N0`4`!$`?'V3GO__E^4K0/GC`P"JP0``D&`B`I$"``#P0J`>D2<\
M0/D$``#PI@!`^8$`@%*$@!Z19A``J>8`@)(!!`"Y(0"`T@,$`/EG"`&IXE]`
MN5\$`'$M`0!4'R`#U200`!&@>&'XQ,PDBR$$`)%?``%K8&@D^$S__U1%$``1
M=B("D4(,`!$!``"09<PEBR'@+)'`#D#Y!`"`TK^`'_C$_O^7]0,`*J`$`#1V
M(@*1]Y,!D<`.0/E.__^7````\.$#%ZH`@!21=```E``$`+1S(@*18`Y`^:;^
M_Y<-__^7E-9'^>$W0/F``D#Y(```RF`$`+7@`Q4J\U-!J?5;0JGW&T#Y_7O'
MJ,`#7];M_O^7TP``D&(B`I%`#`#Y(`,`M+4``/`'__^7H,I'^0``0+ED__^7
M'\0H.:;__Q?`#D#YN/[_E_4#`"K9__\7P`I`^6```+35!@"4WO__%^$#%ZH`
M``#P`*`2D4P``)3`"@#Y`/O_M,T&`)36__\7$?__ER``@%*__O^7'0"`TAX`
M@-+E`P"JX0-`^>(C`)'F`P"1H```\`#\1_FC``#P8_!'^:0``/"$Q$?Y>O[_
ME]'^_Y>@``#P`-!'^4```+2%_O\7P`-?UA\@`]7```"0```"D<$``)`A``*1
M/P``Z\```%2A``#P(=Q'^6$``+3P`P&J``(?UL`#7];```"0```"D<$``)`A
M``*1(0``RR+\?]-!#(&+_P>!ZR'\09/```!4H@``\$+@1_EB``"T\`,"J@`"
M'];``U_6_7N^J?T#`)'S"P#YTP``D&`"0CE``0`UH```\`#81_F```"TP```
MD``$0/F+_O^7V/__ER``@%)@`@(Y\PM`^?U[PJC``U_6WO__%Q\@`]7]>[RI
M_0,`D?-3`:F@!@"T]V,#J?<#`*J@``#P`/A'^1@`0/DX!@"T]5L"J?8#`:H5
M`(!2X`)`.1_T`'$$&$!ZP0(`5!,#0/G3`0"TM7Y`D_0#&*H?(`/5X@,5JN$#
M%ZK@`Q.J>?[_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;0JGW8T.IX`,3
MJO-30:G]>\2HP`-?UO4#%ZJ@'D`X'_0`<0080'JA__]4M0(72^7__Q>4`AC+
MM08`D7,"%8N4_D.3U`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`@-+I
M__\7$P"`TO=C0ZGF__\7'R`#U?U[O*G]`P"1]5L"J;8``/#UTP"1P=9'^?-3
M`:FT``#P\P,`JB``0/G@'P#Y``"`TI3Z1_GA`Q6JX`,3JK/__Y<``@"TA`)`
M^>4W@+F"#`6+0P1`^8-X)?CC_O^T'R`#U4,(0/E#!`#Y0B``D:/__[7A`Q6J
MX`,3JJ3__Y=`_O^UUM9'^>$?0/G``D#Y(```RJ```+7S4T&I]5M"J?U[Q*C`
M`U_68_[_E_U[N:G]`P"1\U,!J;0``/#S`P"J]5L"J?4#`:KW8P.I^6L$J8'6
M1_F@`D`Y(@!`^>(W`/D"`(#2'_0`<;46E9K@`Q6JJ?[_E_<#`*KADP&1X`,3
MJH/__Y=@"`"T]@,`JJ+^_Y<?`!?K`@<`5/AG@+FY``#P&/-]TV`"0#D?]`!Q
M!!A`>J`,`%3C`Q.J'R`#U6(<0#A?]`!Q1!A`>J'__U1C`!/+8WQ`DSG[1_G@
M"@"1```#BS<#0/E$_O^7X&HX^,`+`+3C9X"YX`,3JB(#0/D!%$`X0WAC^#_T
M`'$D&$!Z80``.<```%0"%$`X8AP`.%_T`'%$&$!Z@?__5*$'@%(``(#2810`
M.*)J8#AB:"`X``0`D:+__S4``(!2E-9'^>(W0/F!`D#Y00`!R@$(`+7S4T&I
M]5M"J?=C0ZGY:T2I_7O'J,`#7]8!`(#2'R`#U:)J83C":B$X(00`D:+__S7N
M__\7N0``\/LK`/D@^T?Y&P!`^6`#0/E`!0"TX`,;JA8`@%(?(`/5`8Q`^.(#
M%BK6!@`1H?__M4`,`!$`?'V3P0``D"*(0+E"`@`U(@"`4B*(`+D%_O^7^@,`
MJL`#`+38?GV3X0,;JN(#&*H[_O^7(?M'^<!^0),Z``#Y``0`D5][(/CV9P"Y
M^RM`^:/__Q?A`P"JX`,;JI#]_Y?Z`P"J(?M'^2```/E@`0"TP'Y`D]A^?9/R
M__\7`P"`TJ/__Q<``H#2%@"`4M[__Q?[*P#YUOW_E_LK0/D``(`2N/__%_U[
MLJG]`P"1]5L"J;4``/"AUD?Y(@!`^>)O`/D"`(#2P```M/-3`:GT`P"J`0!`
M.4$!`#7S4T&IM=9'^>%O0/F@`D#Y(```RB`)`+7U6T*I_7O.J,`#7];W8P.I
MV_W_E_<#`*J`!P"T&```\!@#$9'Y:P2I^F,!D=G%A5+@`Q>J9OW_ER`%`+0!
M,$%X$TP`D3^X`'%`__]4/P`9:V`%`%3@`Q2J`?[_E_8#`*K@`Q.J_OW_E\`"
M``L`"``1`'Q`D[+]_Y?E`Q.JY`,4JN,#&*KS`P"J`@"`DB$`@%+W_?^7X@,:
MJN$#$ZH``(!2G_W_EQ\$`#&@``!4X&M`N0`,%!(?$$!QX`(`5.`#$ZK__/^7
MX`,3JLG]_Y?@`Q>J/_W_ET#[_[4?(`/5X`,7JDO]_Y?@`Q2J7?W_E_-30:GW
M8T.I^6M$J;W__Q=@"D`Y@/G_--3__Q?S4T&I]V-#J;?__Q?@`Q.JI___E^K_
M_Q?S4P&I]V,#J?EK!*ET_?^7'R`#U?U[M:GA`P"J_0,`D?-3`:FS``#P]`,`
MJF/61_GBHP"1``"`4F0`0/GD5P#Y!`"`TE[]_Y?@`0`UX3M`N0(`E%(A#!02
M/Q!`<2000GI@`0!4<]9'^>)70/EA`D#Y00`!RH$!`+7S4T&I_7O+J,`#7]8`
M`(!2]___%^`#%*I!`(!2'OW_EQ\``''@%Y\:\?__%T[]_Y<?(`/5#`J"TO]C
M+,O]>P"I_0,`D?-3`:FS``#P8M9'^?5;`JGV(P&1]V,#J?4#`*KW`P&J0`!`
M^>`G"/D``(#2X0,6J@```/#B_X'2`"`1D<7\_Y<?``!QK04`5`($`%&A``#P
M(<A'^</*8C@X`$"Y0P,`-0($`#14?$"3X`,6JN(#%*KA!8!28_W_ET`#`+3@
M`Q@J:/W_E^,#%*KB`Q:JX0,5JB#]_Y=SUD?YX2=(^6`"0/D@``#*P`,`M0P*
M@M+]>T"I\U-!J?5;0JGW8T.I_V,LB\`#7];B`P`JX06`4N`#%JI4?$"3X@,4
MJDK]_Y<`_?^UX`,8*D_]_Y?B`Q>JX0,5JK3\_Y?H__\7H```\`#(1_D8`$"Y
MX`,8*D;]_Y?B`Q>JX0,5JJO\_Y??__\7`?W_E_U[OZF@``#P_0,`D0#(1_D`
M`$"Y._W_E_U[P:BB``#P(P``\`$``/!"Z$?Y8V`(D2%@$9$W_?\7_7N^J?T#
M`)'S"P#YLP``\'/*1_E@`D"Y+/W_E^O__Y=@`D"Y*?W_E_,+0/D$``#P_7O"
MJ(1@'I'C`P2J`@``L`$``/!"8">1(>`1D04`@%*Z_/\7'R`#U0P*A-+_8RS+
M``B"TOU[`*G]`P"1\U,!J;0``/#SXP"1]5L"J?9C((L5`(#2@-9'^0$`0/GA
M)Q#Y`0"`TEW\_Y?D`P`J!0``\`,``/"E0!*18V`2D2(`@M(A`(!2X`,3JB#]
M_Y?@`Q.JX0,6J@(`@M),_/^7@`'X-_,#`*H`!``1`'Q`D\O\_Y?U`P"JP```
MM'-^0)/A`Q:JX@,3JEG\_Y>_:C,XE-9'^>$G4/F``D#Y(```R@`!`+7@`Q6J
M#`J$TOU[0*GS4T&I]5M"J?]C+(O``U_6I_S_E\K__Q<?(`/5#!Z"TO]C+,O]
M>P"I_0,`D?EK!*FZ``#P0M='^?-3`:GS`P&J]5L"J>&3`9'U`P"J0P!`^>-W
M"/D#`(#2````\`"@$I')_?^7]`,`JN$%@%+@`Q6JN_S_ET`"`+3A`Q6J````
M\`#@$I$H_O^7X`,5JEK71_GB=TCY00-`^4$``<IA#`"U#!Z"TOU[0*GS4T&I
M]5M"J?EK1*G_8RR+P`-?UN`#%:KW8P.ITOS_EQ<``/#X`P`JX2(3D>`#$ZKY
M^_^7\P,`J@`*`+09``#P]J,#D3E#$Y'[*P#Y&P``\'NC#Y%@`D`Y(`8`-+0`
M`+3A`Q.JX`,4JG_\_Y>`!``TX`,3JKS\_Y?B`P`J8,(@BP#P7S@?O`!QX0``
M5$($`%%@PB*+?\HB.`#P7S@?O`!Q8/__5``'`!$"``(+7_P_<0P#`%3D`Q.J
MY@,5JN4#&:H#``#P8V`3D0(`@M(A`(!2X`,6JJC\_Y?BHP&1X0,6J@``@%)0
M_/^7H```->![0+D`#!02'R!`<6`"`%3A(A.1``"`TL3[_Y?S`P"J0/K_M?=C
M0ZG[*T#YKO__%Y0``+2``D`Y'[@`<8```%3S`QNJ(@"`4MS__Q>`!D`Y`/[_
M-/O__Q?@`Q:J(0"`4OK[_Y=@_?\UX0,6J@```/``X!*1Q_W_E^`#%JI+_/^7
M]V-#J?LK0/F<__\7]V-#J97__Q?W8P.I^RL`^1_\_Y<"`$`YX0,`JN(``#0?
M(`/5(00`D5^\`'$`$(&:(@!`.8+__S7``U_68`@`M/U[OJG]`P"1\PL`^?,#
M`*H!`$`YH08`-&7\_Y<"!`#18@("BW\"`NNC``!4-```%$($`-%_`@+KX`$`
M5$``0#D?O`!Q8/__5'\"`NN"!0!40@0`T7\"`NO@``!40`!`.1^\`''@`0!4
M0@0`T7\"`NMA__]40`!`.1^\`'%@`P!4\PM`^0```/#]>\*H`$`3D1/\_Q=`
M`$`Y'[P`<8$``%1"!`#1?P("ZV/__U1"`!/+``"`TD$(`)$_!$#Q"`$`5,``
M`)`$H`*10@0`D>$#$ZK@`P2J`P""TOG[_Y?S"T#Y_7O"J,`#7];S"T#Y````
M\/U[PJ@`H`^1^?O_%W\"`NL!_?]4W/__%P```/``H`^1\_O_%_U[N*DA``#P
M(6`(D?T#`)'S4P&ILP``\````/!CUD?Y]5L"J0"`$Y'W8P.I%@``\!<``/!F
M`$#YYC\`^08`@-(8``#0)AQ!J>8?!:D4``#0)!1"J>07!JDA8$!YX>,`>90"
M%9'U,P&1*/W_EP```-``P!.1)?W_EP```-``X!.1(OW_EP```-``(!21'_W_
ME\!"%)$=_?^7````T`"`%)$:_?^7X*(2D1C]_Y<`PQ21%OW_E^`#%*H4_?^7
M````T`!`%9$1_?^7````T`#@$I$._?^7````T.$#%:H`@!61S/S_EX```+3A
M`P"JX`,4JC#]_Y?A`Q6J````T`#@%9'$_/^7X0,`JH```+0```#0`,`/D2?]
M_Y?A`Q6J````T`!`%I&[_/^7X0,`JB`"`+3@HA*1'_W_E\!"%)$!``#0(2`7
MD1O]_Y=SUD?YX3]`^6`"0/D@``#*@`,`M?-30:GU6T*I]V-#J?U[R*C``U_6
MX0,5J@```-``@!:1I?S_E^$#`*J```"T`,,4D0G]_Y?J__\7`"J(TN(31OA`
MZJOR8(C)\J`HZ/)?``#K8?S_5.*31GC`J8=27P``:^'[_U3AKP&1\?__%US[
M_Y<?(`/5_7N]J?T#`)'S4P&ILP``T+0``/!AUD?Y@!)`N2(`0/GB%P#Y`@"`
MTA\$`#$@`0!4<]9'^>(70/EA`D#Y00`!RB$"`+7S4T&I_7O#J,`#7];ADP"1
M````T`#`%)%Y_/^7X0,`J@``@%*A``"T(`!`.1_``'$$&$!ZX`>?&H`2`+GL
M__\7.?O_E_U[OZG]`P"1&OO_E\GZ_Y=```"T``!`^?U[P:C``U_6_7N[J?T#
M`)'S4P&ILP``T.$3`9%BUD?Y]5L"J18``-#W&P#YUT(7D?4#`*K@`Q>J0P!`
M^>,G`/D#`(#25_S_EX```+0!`$`Y]`,`JL$!`#7A`Q6JP$(7D;C\_Y=SUD?Y
MX2=`^6`"0/D@``#*X`,`M?-30:GU6T*I]QM`^?U[Q:C``U_6X0,5JLKZ_Y>`
M_O^UX`,5JF/[_Y?V`P"JX`,4JF#[_Y?``@"+``@`D17[_Y?F`Q2JY`,5J@4`
M`-`#``#0I2`3D6-@$Y$"`("2]`,`JB$`@%)7^_^7X0,4JN`#%ZJ6_/^7WO__
M%_;Z_Y<?(`/5##:0TO]C+,NB``#P0D``D?U[`:G]0P"11IQ`J?5;`ZFU``#0
M\U,"J?3S`9&AUD?Y]V,$J?<#`*K@(T"1YA\(J20`0/D$U`#Y!`"`TDHL0JD8
M``#02"1#J>$#%*I$%$2I`*,2D48<1:GFGPFI3`Q`^>Q+`/E",$#YXE<`^>HO
M"ZGH)PRIY!<-J0C\_Y>```"T`0!`.?,#`*H!%0`U^6L%J93__Y?Y`P"J(!``
MM.`#&:H@^_^7`/A_TP`$`)'5^O^7)`-`.?8#`*J$`0`T&@``T/,#%JI:HQ>1
MX`,3JN,#&JH"`("2(0"`4A;[_Y=S"@"1)!]`."3__S4!``#0^>,"D2#`#Y$#
M```4((=`^&`)`+3A`Q2JY?O_E_,#`*I@__^T`0!`.2'__S0X_?^7X/[_-.`#
M$ZK+^O^7\P,`JN`'`+3@`Q.J^_K_E_H#`*K@`Q:J^/K_EUH#``M:$Q`1&0``
MT%I_0)/@`QJJJOK_E^<#%JKD`Q.J)4,3D08``-`#``#0QL`7D6/@%Y$"`("2
M]@,`JB$`@%+K^O^7X`,6J@$X@%+`^O^7'P0`,:$``%1Q^O^7!0!`N;]$`'&!
M"@!4XH,#D>$#%JH``(!2>OK_E_,#`"J`!0`TH```T.0#%JKC`D#Y`@``T`#D
M1_E"(!F1(0"`4A0`@-(``$#Y:OK_E_EK1:G@(T"1M=9'^0'40/F@`D#Y(```
MRB`D`+7@`Q2J##:0TOU[0:GS4T*I]5M#J?=C1*G_8RR+P`-?UOH#`I$9`(!2
M4]MY^+,!`+1@`D`Y8`$`-#D'`!'@`Q.J[/S_ER#__S3@`Q.J?_K_E_,#`*J@
M]O^U4]MY^+/^_[43`(#2L?__%^#S0+D`#!02'Q!`<4'Z_U3[<P:I^_M`N3+Z
M_Y=_`P!K8`4`5/MS1JG+__\7]F,"D1,`@%(?(`/5P-IS^(`!`+3A`Q2J<P8`
M$7C[_Y=@__^T`0!`.2'__S1B^O^7^0,`JF#N_[7`VG/XP/[_M:`!@-)(^O^7
M&0``T/8#`*HY@Q>19`J`4G+__Q>@``#0Y`,6JN,"0/D"``#0`.1'^4(@&)$A
M`(!2%`"`T@``0/D=^O^7^6M%J;/__Q?V_O^7X`,3JDCZ_Y?T`P"JKO__%^#S
M0+D`(``2'P`'<6'Z_U3@`QJJ+/K_E^$#%*KT`P"J````T`"`&I%-^_^7``L`
MM/H"0/DX^O^7X0,`JN`#&JIM_?^7^P,`JB`*`+3@`QNJ9?K_E_H#`*H?#`!Q
M#0(`5`!\0),!``#0`!``T2&@&I%@`P"+'/K_ER`!`#5?$P!QH!``5$`3`%%@
MPR"+`/!?.!^\`'$`$`!4'R`#U:#^_Y?````UX`,;J@$`@%)*^O^7]P,`*@`'
M`#4!``#0(2`7D0```-``P!21C?O_ESE#$Y%]^?^7%P``T`<``-#G8!Z1Y@,`
M*OH#!ZKE`QFJY`,6JN`#%*H#``#0`@"`DF,@&Y$A`(!2]V(;D3OZ_Y<1```4
MQ?G_EP``0+D?1`!Q00(`5&GY_Y?Z`P#Y<P8`$>8#`"KG`Q,JY0,9JN0#%JKC
M`Q>JX`,4J@(`@)(A`(!2*OK_E^`#%*H!.(!2__G_EQ\$`#&`_?]4X`,6J@/Z
M_Y?A`Q2J`*,2D6+[_Y?@`Q2JDO[_E_EK1:G[<T:I2___%_L"0/FO__\70@"`
M4B$"@)+ZHP:1.?G_E^$#&JK@`Q<JP@"`TJ7Y_Y?@HT8Y@```->"G1CD?#`%Q
M0`@`5`(`@%(!`(#2X`,7*BSY_Y?U!0"4\P,`J@4``!3B`P`JX0,:JN`#$ZH%
M!@"4X0,:JN`#%RH"`)#2D?G_EQ\``''L_O]4X`,7*OSC!9'L^?^7&@``T.$#
M$ZJ;HP"1\P,<JEJC%Y'W@P61X`,7JCH&`)0?(`/5Y!9`..`#$ZKC`QJJ<PH`
MD0(`@)(A`(!2Z/G_EW\#$^L!__]4Y@,<JB5#$Y'D`Q:JX`,4J@<``-`#``#0
MYV`>D6/@&I$"`("2(0"`4O^#!CG:^?^7M?__%_<&0/DW\/^TX`,7JM'Y_Y<?
M#`#QJ>__5``0`-$!``#0X`(`BR'`&I&*^?^7'P``<7L3EYIU__\7X*M&.1\$
M`7&A]_]4X*]&.1\,`7%!]_]4X+-&.1\@`7'A]O]4X+=&.1\4`7&!]O]4X`,7
M*D(`@%(A!X"2W_C_E^$#&JK@`Q<J(@6`TDOY_Y?F`QJJ)4,3D>0#%JK@`Q2J
M!P``T`,``-#G8!Z18^`:D0(`@)(A`(!2K/G_EX?__Q?Y:P6I^W,&J4SY_Y<?
M(`/5_7NXJ:```-#]`P"1]V,#J;<``-#S4P&I],I'^?5;`JGUTP&1`=1'^?EK
M!*F``D"Y(@!`^>(_`/D"`(#2]3<`^7KY_Y?S`P"J@`)`N7?Y_Y?B`P"J8^)"
M.0```-#A`Q6J`$`4D4/D`CEF^O^7@```M`$`0#D_Q`!QH!,`5%W]_Y?VRD?Y
MP`)`N6CY_Y<!``#08P&`4B'`&Y$B`(!2P_C_EV`6`+2A``#P-2`"D0`(0/GA
M,P#YH09`N=H"0+D_!`!Q&!1`^0T&`%09@(!2%`"`4C,`@%(9!*!R^W,%J0H`
M`!1A"$#YX`,<JBCY_Y>A!D"Y(`0`-7,&`!&4!@`1?P(!:ZH#`%3@`QHJ2/G_
MEX)^0)/A`QBJ`P"`4@CY_Y?[`P"JX!(`M`,`0/FD!D#Y8`Q`N=H"0+D``!D*
M'P`0<9S8<_@`_?]4X`,:*CCY_Y=A`T#Y0P"`4@(`@-)8^?^7X0,`JN`#'*H)
M^?^7V@)`N:$&0+D@_/\T(`0`41\`%&O@"P!4^W-%J>`#&BHH^?^78P"`4@$`
M`-`B`(!2(>`;D8/X_Y?S`P"JH`$`M/3*1_F``D"Y'OG_EV$*0/D"``#00@`<
MD2$`0/F!^/^78`I`^0``0/D`#$"Y@`^P-_3*1_F``D"Y$OG_EP$``-!C`(!2
M(2`<D2(`@%)M^/^7\P,`JJ`!`+3A-T#Y````T`#@$I']^?^7]0,`JH`"0+E5
M#`"T`_G_EV$*0/GB`Q6J(0!`^6?X_Y?WRD?YX#-`^10@`I'@`D"Y^OC_E_,#
M`*K@`D"Y]_C_ER(`@%(!``#0(4`<D2?X_Y<"``#0X0,`JD*@')'@`Q.J5OC_
ME^`"0+GL^/^7X@,`JN$W0/D```#07^0".0"@$I'<^?^7@`H`^?,#`*I@!0"T
M`3B`4N`#$ZK4^/^7`00`$3\$`'$$B%%Z80D`5*```-`:U$?YX3]`^4`#0/D@
M``#*8`@`M?-30:GU6T*I]V-#J?EK1*G]>\BHP`-?U@`$0#F`[/\T8O__%S\$
M`'$M]/]4X#-`^3,`@%+URD?Y%"`"D0(``!2Z`D"YX`,:*L/X_Y?A`QBJ'?C_
MEX`&0+ES!@`1'P`3:PS__U3@RD?Y^W-%J1H`0+F0__\7@`9`^8/]_Y>`"@#Y
M\P,`JD#Z_[4```#0`,`<D?MS!:F8^/^7H```\-H"0+G@,P#Y@___%^`S0/GA
MRD?Y`"`"D3H`0+D!!$"Y(`0`41\`%&M![_]4U___%Z+X_Y?@,T#Y8@I`^0`@
M`I$!!$#Y0`!`^2$`0/D/^_^7G/__%X`"0+F8^/^780I`^2$`0/EI^/^7@/__
M%_MS!:E2^/^7X3-`^?MS!:GC`P`J/"`"D0```-#B`Q.J`&`=D8$'0/DA`$#Y
M</C_EQ\@`]7]>[ZI_0,`D?-3`:GT`P"J+OS_EP$`0#GS`P"JP0``-``$`)$_
MO`!Q<Q*`F@$`0#F!__\UW_S_EY\"`/$$&$!Z@0``5/-30:G]>\*HP`-?UH`"
M0#F`__\T`0``T.`#$ZHAP!>1@@"`TO3W_Y?`_O\UX`,4JO-30:G]>\*H5?K_
M%_^#"M&F``#0XF,`D07@`)$)X`&1Y`,"JOU[`*G]`P"1P=1'^2,`0/GC3P'Y
M`P"`TJ$`0+F$0`"1HX1`^"$(P%J!`!_X/P$%ZV'\8--H_&C3"!UXDB?<>-,A
M'`A3YQQPD@/A0ZHA``>J(0`#JH&`'_@!_O]410`(D4$`0/E"(`"10P1`^40<
M0/EC``'*03!`^2$`!,HA``/*(_Q?TV$$`:HA?$"203P`^5\`!>MA_O]4!21`
MJ2LSC]('($&I2U"K\N,/0/DD=)W2HOQ;TZW\0M-"%`6J8P`+BP$!!\JM>06J
M(0`)BB3;K?(A``C*(D`BBR']0M,A>`FJ0@`#BPH00/DO?$"2[`$'RB$`#<KC
M$T#Y0@`*"XP!!8HA``**C`$'RF,`"XN,`0B+4?Q;TS$6`JJ,`0.+\A=`^8,!
M$8M>_$+3(0`/RE(""XMN?!M3(0`'BW!\>]/#>P*JC`$1"R$`$HL0`@ZJH@$#
MRBX`$(OR&T#YL7U`DD(`#(J>_4+30@`1RDT""XM"``^+SWU[T\Y]&U-"``V+
M[P$.JLQ[#*I.``^+0@`/"_*_0ZDA`!`+;0`,RG!\0)*M`0&*/OQ"TZT!$,K!
M>P&JK0$1B]%]>]-#`@N+SGT;4ZT!`XN#`0'*DGU`DF,``HHQ`@ZJ8P`2RJX!
M$8MC`!"+[P$+BTS\0M-O``^+HP$1"X)Y`JK0?7O3SGT;4SY\0)(0`@ZJ+``"
MRF'\0M/M`1"+C`$#BB-X`ZKA`1`+C`$>RNZ_1*F,`1*+L7U[TZU]&U,Q`@VJ
M4GQ`DC#\0M/.`0N+C@$.BTP``\K-`1&+C`$!BHP!$LH!>@&JX@$+BXP!'HNO
M?1M3L'U[TQ`"#ZJ-`0*+P@$1"VP``<KO+T#YK@$0BWY\0)*,`0**C`$>RE'\
M0M,B>@*JXP$+BXP!$HO/?1M3T7U[TXX!`XLQ`@^JHP$0"RP``LK-`1&+[S-`
M^3)\0)*,`0.*</Q"TXP!$LH#>@.JX0$+BXP!'HNO?1M3L'U[TQ`"#ZJ-`0&+
MP0$1"TP``\KO-T#YK@$0BUY\0)*,`0&*C`$>RC'\0M,A>@&JX@$+BXP!$HO/
M?1M3T7U[TXX!`HLQ`@^JH@$0"VP``<K-`1&+[SM`^7)\0)*,`0**4/Q"TXP!
M$LH">@*JXP$+BXP!'HNO?1M3L'U[TQ`"#ZJ-`0.+PP$1"RP``LKO/T#YK@$0
MBSY\0)*,`0.*C`$>RG'\0M,C>@.JX0$+BXP!$HO/?1M3T7U[TXX!`8LQ`@^J
MH0$0"TP``\K-`1&+[T-`^5)\0)*,`0&*,/Q"TXP!$LH!>@&JX@$+BXP!'HNO
M?1M3L'U[TQ`"#ZJ-`0*+P@$1"VP``<KO1T#YK@$0BWY\0)*,`0**C`$>RE'\
M0M,B>@*JXP$+BXP!$HO/?1M3T7U[TXX!`XLQ`@^JHP$0"RP``LK-`1&+[TM`
M^3)\0)*,`0.*</Q"TXP!$LH#>@.JX0$+BXP!'HNO?1M3L'U[TQ`"#ZJ-`0&+
MP0$1"TP``\I1?$"2K@$0BXP!`8HB_$+3C`$1RD%X`:J,`1*+TGU[T\Y]&U.B
M`1`+4@(.JN^[2:E0_$+3[P$+B\X!"XN/`0^+;``!RNT!$HMC?$"2C`$"B@)Z
M`JJ,`0/*[P$2"XP!$8NP?7O3L7T;4RT``LKR5T#Y$`(1JHX!#HLQ?$"2K0$/
MBLP!$(NM`1'*_OU"TT$""XO/>P^JK0$#BY)]&U.M`0&+@VD;4\$!$`M,``_*
M\%M`^4)\0)*,`0&*8P`2JHP!`LH0`@N+BP$1BZX!`PMK`1"+,?Q"T_!?0/DA
M>@&JHP$#B\S]6]/M`0'*C!4.JJT!`TH#`@2+T/U"TY(!"PL.>@ZJ;$$LBRL`
M#LJM`0*+;`$,2D+^6]./02^+3/Y"TZT!`XM"%!*JDGD2JE``#0OC,TRIHD$B
MB\T!$LJB`0)*#?Y"TT%`(8MK``2+`_Y;TV,4$*KK`0N+L'D0JF\`"PMC02.+
M2P(0RF,!`TJ,`02+;D`NB^+]6]/C_4+3+``,BT(4#ZIO>`^JX0]-J5$`#`N"
M02*+#`(/RH(!`DHM_D+3*P`$BR'^6]-L``2+RP$+BR$4$:I#0#*++@`+"V,`
M#(OL<T#YPOU;T[%Y$:I"%`ZJ84$ABXL!!(O,_4+34@`#"XYY#JKM`1'*['=`
M^:$!`4IB0"*+(P(.RBU`,(MB``)*0?Y;TZL!"XLA%!*J@P$$BTW^0M-,0"^+
M,``+"ZUY$JJ#`0.+84$AB^Q[0/G+`0W*80$!2@+^6],K0#&+0A00JHP!!(L1
M_D+33P`#"S!Z$*IK`0R+8D`BB^Q_0/FC`1#*X?U;TV(``DHA%`^J0T`NBXP!
M!(LQ``L+8P`,B^[]0M/L@T#YSWD/JB+^6]-A02&+"P(/RD(4$:IA`0%*BP$$
MBRS^0M-.``,+D7D1JF)`(HOLAT#YXP$1RBU`+8MB``)*P?U;TZL!"XLA%`ZJ
M@P$$B\W]0M-,0#"+,@`+"ZYY#JJ#`0.+84$AB^R+0/DK`@[*80$!2D+^6],K
M0"^+3?Y"TT(4$JJ,`02+4``#"VL!#(NL>1*J8D`BB^V/0/G#`0S*`?Y;TV(`
M`DHA%!"J0T`QBZT!!(L1_D+3+P`+"S!Z$*IC``V+84$AB^V30/F+`1#*80$!
M2N+]6]-"%`^JJP$$BRU`+HON_4+34@`#"\]Y#ZJK`0N+8D`BB^V70/D#`@_*
M8@`"2D'^6],A%!*J3$`LBZ,!!(M-_D+3,0`+"X,!`XNM>1*J84$AB^R;0/GK
M`0W*(OY;TV$!`4I"%!&J*T`PBXP!!(LP_D+33@`#"VL!#(L,>A&J8D`BB_&?
M0/FC`0S*P?U;TV(``DHA%`ZJ0T`OBS$"!(O/_4+3,``+"^YY#JIC`!&+84$A
MB_&C0/F+`0[*80$!2@+^6],K`@2+0A00JBU`+8L1_D+33P`#"S!Z$*JM`0N+
M8D`BB^NG0/G#`1#*8P`"2N']6],A%`^J8@$$BVM`+(OL_4+3,@`-"X]Y#ZH#
M`@_*H4$ABV$``4I-_D+3(T`NBZYY$JKL-U6I4?Y;TS$6$JIB`0*+2P`1BX0!
M!(ML?7O3:WT;4V,`!(N,`0NJ1``1"^(!#JK+`0\*80`,BT(`!(I"``NJD?Q"
MTXN;E](D>@2J:^.Q\D)`,(NM`0N+,7Q[TR%\&U-"``V+,0(!JF,`#`M!`!&+
M0@`1"^U'5JG,`02JD``."HP!`XJ,`1"J</Q"TP-Z`ZJ,02^+,'P;4R]\>].M
M`0N+[P$0JH$``ZJ-`0V+K`$/BW``!`HA``**,0(+BR$`$*I0_$+3`GH"JB%`
M+HN0?7O3CGT;4Q`"#JHL`!&+H0$/"VT``JKONT#Y40`#"HX!$(NM`0&*K0$1
MJC'\0M,A>@&JI$$DB^T!"XO/?7O3SGT;4XT`#8OO`0ZJA`$0"TP``:HQ``(*
M\+]`^:X!#XN,`02*C`$1JI'\0M,D>@2J@T$CBPP""XO0?7O3SGT;4VP`#(L0
M`@ZJHP$/"RT`!*J1``$*[\-`^8X!$(NM`0.*K0$1JG'\0M,C>@.JHD$BB^T!
M"XO/?7O3SGT;4TT`#8OO`0ZJ@@$0"XP``ZIQ``0*\,=`^:X!#XN,`0**C`$1
MJE'\0M,B>@*J@4$ABPP""XO0?7O3SGT;4RP`#(L0`@ZJH0$/"VT``JI1``,*
M[\M`^8X!$(NM`0&*K0$1JC'\0M,A>@&JI$$DB^T!"XO/?7O3SGT;4XT`#8OO
M`0ZJA`$0"TP``:HQ``(*\,]`^:X!#XN,`02*C`$1JI'\0M,D>@2J@T$CBPP"
M"XO0?7O3SGT;4VP`#(L0`@ZJHP$/"RT`!*J1``$*[]-`^8X!$(NM`0.*K0$1
MJG'\0M,C>@.JHD$BB^T!"XO/?7O3SGT;4TT`#8OO`0ZJ@@$0"XP``ZIQ``0*
M\-=`^:X!#XN,`0**C`$1JE'\0M,B>@*J@4$ABPP""XO0?7O3SGT;4RP`#(L0
M`@ZJH0$/"VT``JI1``,*[]M`^8X!$(NM`0&*K0$1JC'\0M,A>@&JI$$DB^T!
M"XO/?7O3SGT;4XT`#8OO`0ZJA`$0"TP``:HQ``(*\-]`^:X!#XN,`02*C`$1
MJI'\0M,D>@2J@T$CBPP""XO0?7O3SGT;4VP`#(L0`@ZJHP$/"RT`!*J1``$*
M[^-`^8X!$(NM`0.*K0$1JG'\0M,C>@.JHD$BB^T!"XO/?7O3SGT;4TT`#8OO
M`0ZJ@@$0"XP``ZIQ``0*\.=`^:X!#XN,`0**C`$1JE'\0M.!02&+#`(+B]!]
M>]/.?1M3+``,BQ`"#JJA`0\+C@$0BXP!$`LB>@*J[T-=J6T``JI1``,*K0$!
MBJT!$:HQ_$+3(7H!JJ1!)(LQ``(*[0$+B\]]>]/.?1M3A``-B^\!#JI-``&J
MC@`/BZT!#(JM`1&JD?U"TQ`""XNC02.++7H,JM%]>]/.?1M3C``/"V,`$(LQ
M`@ZJ)``-JK`!`0KN\T#Y;P`1BX0`#(J$`!"JD/U"TQ!Z#*J"0"*+Q`$+B^Y]
M>]/O?1M3;``1"T(`!(O.`0^JI`$0JA$"#0KO]T#Y0P`.BX0`#(I.``X+A``1
MJI']0M,L>@RJ@4`ABW%\&U/O`0N+8V@;4R\`#XMC`!&J!`(,JO$!`POC`0.+
MX3]?J8(!$`J$``Z*A``"JH1`+8LM_EO3K141JBL`"XO!_4+3(7@.JH0`"XN"
M`0'*K@$$"T,``TJ-0"V+8D`PB\,ZF-)#3+GR,/Y"T^\!`XO+_5O3$7H1JD(`
M#XMK%0ZJ)``1RN\#0?ER`0(+A``-2DM`*XOM`0.+C$`LB\_]0M-$_EO3[GD.
MJHP!#8N$%!*J(@(.RNT'0?F0``P+2P`+2H1!)(MB02&+K0$#BTO^0M,!_EO3
M<GD2JDT`#8LA%!"JS`$2RN(+0?DO``T+C`$$2@O^0M-$``.+C$$QB^+]6]-P
M>1"JC`$$BT(4#ZKD#T'Y40`,"TL"$,JA02&+80$!2H0``XLK0"Z+[?U"TR'^
M6].O>0^J:P$$BR$4$:KD$T'Y+@`+"X)!(HL,`@_*@@$"2BW^0M.,``.+1$`R
MB\+]6].Q>1&JA``,BT(4#JKL%T'Y30`$"V%!(8OK`1'*80$!2HL!`XLL0#"+
MT/U"TZ']6],.>@ZJC`$+BR$4#:KK&T'Y,``,"X)`(HLD`@[*@@`"2F0!`XM+
M0"^+K_U"TP+^6]/M>0VJ:P$$BT(4$*KD'T'Y3P`+"X%!(8O,`0W*@0$!2HP`
M`XLD0#&+$?Y"T^']6],P>A"JA``,BR$4#ZKL(T'Y,0`$"V)!(HNK`1#*8@$"
M2HL!`XM,0"Z+[OU"TR+^6]//>0^JC`$+BT(4$:KK)T'Y3@`,"X%`(8L$`@_*
M@0`!2F0!`XLK0"V++?Y"T\']6].Q>1&J:P$$BR$4#JKD*T'Y+0`+"X)!(HOL
M`1'*@@$"2HP``XM$0#"+T/U"TZ+]6],.>@ZJA``,BT(4#:KL+T'Y4``$"V%!
M(8LK`@[*80$!2HL!`XLL0"^+K_U"TP'^6]/M>0VJC`$+BR$4$*KK,T'Y+P`,
M"X)`(HO$`0W*@@`"2F0!`XM+0#&+$?Y"T^+]6],P>A"J:P$$BT(4#ZKQ-T'Y
MI`$0RH%!(8M,``L+@0`!2C$"`XLD0"Z+\OU"TX']6]-/>@^JC@`1BR$4#*KQ
M.T'Y!`(/RF)!(HLK``X+@@`"2C$"`XN2_4+30D`MBV3]6]--`!&+A!0+JD)Z
M#*KL/T'Y\0$"RL%!(8N.``T+(0(!2I$!`XLL0#"+</U"T\']6].,`1&+$'H+
MJB$4#JKQ0T'Y2P`0RJ1!)(LM``P+9`$$2C$"`XN+0"^+S_U"TZ3]6]/N>0ZJ
M<0$1BX04#:KK1T'YCP`1"X%!(8L,`@[*C`$!2F$!`XN"02*+Z_U;TT(``8MK
M%0^J2P`+BZ']0M/L2T'Y+7@-JB1")(O!`0W*8GU[TW%]&U,D``1*I4`PBT(`
M$:J#`0.+X?U"TT(`!(LA>`^J8P`%B\;41_E"``,+)P`'"\H!"@MI`0D+J`$(
M"P(D`*D'(`&IXD]!^<$`0/E!``'*"A``^8$``+7]>T"I_X,*D<`#7]:W\_^7
M_7N_J0`0@-+]`P"1P_/_EQ\8`/DF8(32)7&5TL2?F]+#CHK2`CZ<TJ;HK/*E
M^;WR1!>S\D,&HO)">KCR!A0`J00,`:D"?`*I'W@`N?U[P:C``U_6'R`#U?U[
MO*E"?$"3_0,`D?-3`:D4X`"1\P,!JO5;`JGU`P"J]@,"JO=C`ZD%C$*I`'A`
MN:0,`@N_``3K8Y2#FF)T0HNDB@*I(`0`-=_^`'$M!@!4U@(!4==F>I+W`@&1
MV'X&4W<"%XL?(`/58`9`J8`&`*ES`@&18@Y]J8(.`:G@`Q6J8@Y^J8(.`JEB
M#G^I@@X#J5;[_Y=_`A?K@?[_5-8:&$OA`Q>JX`,4JL)^0),9\_^7MGH`N?-3
M0:GU6T*I]V-#J?U[Q*C``U_6%PB`4O<"`$O?`A=K@,(@B]?2EQKX?D"3X@,8
MJ@OS_Y>@>D"YX`(`"Z!Z`+D?``%QX?W_5-8"%TMS`AB+X`,5JCC[_Y?/__\7
M]P,3JN/__Q?]>[RIXP^`$OT#`)'S4P&I]`,`JO,#`:KU6P*I->``D?<;`/D@
M%$#Y-BA`N3<P0+D`(`-3U@K`6@($`!'W"L!:7^``<:/*(#B@PB*+C0D`5`$(
M@%(B``)+`0"`4D)\0).B\_^7X`,3JAK[_Y=__@.I?_X$J7_^!:E_-@#Y=UH.
M*>`#$ZH3^_^780)`^>`#$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA_$C3
M@0H`.6$"0/F!#@`Y809`^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\2-.!
M&@`Y809`^8$>`#EA"D#Y(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(TX$J
M`#EA"D#Y@2X`.6$.0/DA_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3@3H`
M.6$.0/F!/@`Y81)`^2'\6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!2@`Y
M81)`^8%.`#GS4T&I]5M"J?<;0/G]>\2H.//_%P$'@%(B``)+`0"`4D)\0)-7
M\_^7N___%Q\@`]7]>[RI_0,`D?-3`:FT``"0E"(MD?5;`JFU``"0M0(MD90"
M%<OV`P`J]V,#J?<#`:KX`P*J1?+_E_\/E.M@`0!4E/Y#DQ,`@-*C>G/XX@,8
MJG,&`)'A`Q>JX`,6*F``/]:?`A/K(?__5/-30:GU6T*I]V-#J?U[Q*C``U_6
M'R`#U<`#7]8?(`/5HP``L&,$0/F\\O\7_7N_J?T#`)']>\&HP`-?U@`````!
M``(``````"]T;7``````+@````````!005)?5$U01$E2````````5$U01$E2
M``!414U01$E2`%1%35``````5$U0``````!54T52`````%5315).04U%````
M```````N+@```````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`
M````97AE```````O<')O8R\E:2\E<P``````4$%27U1%35```````````%!!
M4E]04D]'3D%-10`````Z`````````"\`````````)7,E<R5S``!015),-4Q)
M0@``````````4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!3@````````!0
M05)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"
M54<``````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%04X]````````
M,0````````!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A<BT`
M````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P
M87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`
M```E<R5S=&5M<"TE=2TE=25S``````````!!4D=6`````!@`````````<&5R
M;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#0Y````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````"UE````````+2T```````!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@
M)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D
M;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H
M=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&
M2"P@)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*
M;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@
M)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M
M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA
M;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO
M9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@
M+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB
M.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H
M)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S
M:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>
M*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N
M*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\[
M"F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O
M<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)
M3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M
M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F
M:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]
M("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE
M>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX
M7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@
M;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I
M<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG
M97-T.PI]("\O("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@
M=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````
M``````!P97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("```````1L#.P@!```@````5([__Y0&``#,D/__(`$``/R0__\T
M`0``/)'__T@!``"$D?__;`$``(R1__^$`0``A)+__^P!```LD___'`(``&R5
M__]L`@``[);__^P"``"$E___%`,``+28__]4`P``[)C__W0#``!$F?__F`,`
M`!R:___0`P``))K__^0#```\G/__4`0``&2<__]D!```?)W__Z`$``!,G___
MV`0``-2?__\`!0``])___R`%``#DH/__5`4``(RG___X!0``G*O__V0&```<
MK/__S`8``-R]___P!@``-+[__Q`'``!,O___2`<``.3`__]\!P``9,'__[`'
M``!LP?__Q`<``!```````````7I2``1X'@$;#!\`$````!@```"DC___,```
M```````0````+````,"/__]``````````"````!`````[(___T@`````00X@
MG02>`T*3`D[>W=,.`````!0```!D````$)#__P0``````````````&0```!\
M`````)#___0`````00Y`G0B>!T*3!I0%0I@!EP)&E@.5!%;6U4'8UT/>W=/4
M#@!!#D"3!I0%E026`Y<"F`&=")X'3];50=C70=[=T]0.`$$.0),&E`6=")X'
M0I<"F`%"V-<`+````.0```"0D/__J`````!!#D"=")X'0I4$E@-$DP:4!6$*
MWMW5UM/4#@!!"P``3````!0!```(D?__0`(```!!#G"=#IX-0I,,E`M#E0J6
M"4N7")@'F0::!0)`"M[=V=K7V-76T]0.`$$+29L$8`K;00M*VT*;!$/;09L$
M0MM\````9`$``/B2__]\`0```$$.X`&=')X;0I48EA='E!F3&D34TT?>W=76
M#@!!#N`!DQJ4&948EA>=')X;09@5EQ9&FA.9%'(*U--!V-=!VME!"T/9VD'4
MTT'8UT&3&I09EQ:8%9D4FA-#T]37V-G:0909DQI!F!67%D&:$YD4`"0```#D
M`0``^)/__Y0`````00ZP`9T6GA5#DQ24$U<*WMW3U`X`00L\````#`(``&B4
M__\P`0```$(.T"!!G8H$GHD$0I.(!)2'!$.5A@26A01"EX0$F(,$:@K=WM?8
MU=;3U`X`00L`'````$P"``!8E?__.`````!!#A"=`IX!1M[=#@`````@````
M;`(``'"5__]4`````$$.()T$G@-"DP)*WMW3#@`````T````D`(``*25___8
M`````$(.T$!"G8H(GHD(0I.(")2'"$.5A@B6A0AK"MW>U=;3U`X`00L``!``
M``#(`@``1);__P0`````````:````-P"```XEO__&`(```!"#O`A09V>!)Z=
M!$*9E@2:E01#DYP$E)L$0Y6:!):9!%P*W=[9VM76T]0.`$$+0IB7!)>8!$R;
ME`1R"MC70=M!"U78UT';09>8!)B7!$'8UT*8EP27F`1!FY0$$````$@#``#D
ME___*``````````X````7`,``/B7__\8`0```$(.()T$G@-"DP)@"M[=TPX`
M0@M4"M[=TPX`00M#"M[=TPX`0@M##@#3W=XT````F`,``-28___,`0```$$.
M@`&=$)X/1),.E`U&E0R6"Y<*F`D"4`K>W=?8U=;3U`X`00L``"0```#0`P``
M;)K__X@`````00XPG0:>!4*3!)0#4`K>W=/4#@!!"P`<````^`,``,R:__\@
M`````$$.$)T"G@%&WMT.`````#`````8!```S)K__^P`````00Y0G0J>"4*3
M")0'1)4&E@5"EP17"M[=U]76T]0.`$$+``"@````3`0``(B;__^D!@```$(.
ML(,"0YVT()ZS($.5L""6KR!"D[(@E+$@0Y>N()BM(%N:JR"9K"`"6-K93=W>
MU]C5UM/4#@!!#K"#`I.R()2Q()6P():O()>N()BM()FL()JK()VT()ZS(%><
MJ2";JB!%W-MCVME&F:P@FJL@FZH@G*D@`F$*VME!W-M!"P)PV=K;W$&:JR"9
MK"!!G*D@FZH@`&@```#P!```C*'__PP$````00Z``9T0G@]#EPJ8"4*3#I0-
M0I4,E@M(F0B:!V><!9L&:MS;`ED*WMW9VM?8U=;3U`X`00M#FP:<!5+<VTH*
MG`6;!D$+1)L&G`5)V]Q0"IP%FP9!"T*<!9L&`"P```!<!0``,*7__X``````
M00X@G02>`T*3`I0!4`K>W=/4#@!!"TO>W=/4#@```#0```",!0``N(?__R@"
M````00YPG0Z>#4*3#)0+1)4*E@F7"`)C"M[=U]76T]0.`$$+````````(```
M`,0%``!(I?__P!$```!!#J`%1IU4GE,#9P0*W=X.`$$+'````.@%``#DMO__
M5`````!!#A"=`IX!4][=#@`````T````"`8``!RW__\8`0```$$.0)T(G@=#
MDP:4!4.5!)8#0Y<"F`%G"M[=U]C5UM/4#@!!"P```#````!`!@``_+?__Y0!
M````00Y`G0B>!T.3!I0%0Y4$E@-"EP("50K>W=?5UM/4#@!!"P`P````=`8`
M`&"Y__]\`````$$.0)T(G@="DP:4!4.5!)8#19<"F`%3WMW7V-76T]0.````
M$````*@&``"LN?__!``````````0````O`8``*"Y__\,````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````T",```````"((P````````$``````````0`````````!````
M`````+P!`````````0`````````+`@````````$`````````5P,````````,
M`````````'@<````````#0````````#$4P```````!D`````````0)L!````
M```;``````````@`````````&@````````!(FP$``````!P`````````"```
M``````#U_O]O`````)@"````````!0````````#`#0````````8`````````
MB`,````````*`````````/0$````````"P`````````8`````````!4`````
M```````````````#`````````'"=`0```````@````````#H!0```````!0`
M````````!P`````````7`````````)`6````````!P````````#P$P``````
M``@`````````H`(````````)`````````!@`````````'@`````````(````
M`````/O__V\``````0``"`````#^__]O`````)`3````````____;P`````#
M`````````/#__V\`````M!(```````#Y__]O`````!``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"0'````````)`<````````D!P```````"0'````````)`<````
M````D!P```````"0'````````)`<````````D!P```````"0'````````)`<
M````````D!P```````"0'````````)`<````````D!P```````"0'```````
M`)`<````````D!P```````"0'````````)`<````````D!P```````"0'```
M`````)`<````````D!P```````"0'````````)`<````````D!P```````"0
M'````````)`<````````D!P```````"0'````````)`<````````D!P`````
M``"0'````````)`<````````D!P```````"0'````````)`<````````D!P`
M``````"0'````````)`<````````D!P```````"0'````````)`<````````
MD!P```````"0'````````)`<````````D!P```````"0'````````)`<````
M````D!P```````"0'````````)`<````````D!P```````"0'````````)`<
M````````D!P```````"0'````````)`<````````D!P```````"0'```````
M`)`<````````D!P```````!0FP$``````+!3````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````P4P``````````````````````````
M``"@(```````````````````"*`!``````#_____`````.!3````````Z%,`
M`````````````````/!3`````````%0````````(5````````!!4````````
M&%0``````````````````"!4````````*%0``````````````````+!7````
M````1T-#.B`H1&5B:6%N(#DN,BXQ+3(U*2`Y+C(N,2`R,#(P,#$R,P``+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT
M86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N
M9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R
M<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M````````````````````````````````"P````$````"`````````#@"````
M````.`(````````;`````````````````````0```````````````````!,`
M```'`````@````````!4`@```````%0"````````)```````````````````
M``0````````````````````F````!P````(`````````>`(```````!X`@``
M`````"`````````````````````$````````````````````-````/;__V\"
M`````````)@"````````F`(```````#P``````````4`````````"```````
M`````````````#X````+`````@````````"(`P```````(@#````````.`H`
M```````&`````P````@`````````&`````````!&`````P````(`````````
MP`T```````#`#0```````/0$```````````````````!````````````````
M````3@```/___V\"`````````+02````````M!(```````#:``````````4`
M`````````@`````````"`````````%L```#^__]O`@````````"0$P``````
M`)`3````````8``````````&`````P````@```````````````````!J````
M!`````(`````````\!,```````#P$P```````*`"````````!0`````````(
M`````````!@`````````=`````0```!"`````````)`6````````D!8`````
M``#H!0````````4````5````"``````````8`````````'X````!````!@``
M``````!X'````````'@<````````%`````````````````````0`````````
M``````````!Y`````0````8`````````D!P```````"0'````````!`$````
M```````````````0`````````!``````````A`````$````&`````````*`@
M````````H"`````````D,P``````````````````"```````````````````
M`(H````!````!@````````#$4P```````,13````````$```````````````
M``````0```````````````````"0`````0````(`````````V%,```````#8
M4P```````'(^```````````````````(````````````````````F`````$`
M```"`````````$R2````````3)(````````,`0``````````````````!```
M`````````````````*8````!`````@````````!8DP```````%B3````````
MT`8```````````````````@```````````````````"P````#@````,`````
M````0)L!``````!`FP````````@````````````````````(``````````@`
M````````O`````\````#`````````$B;`0``````2)L````````(````````
M````````````"``````````(`````````,@````&`````P````````!0FP$`
M`````%";````````(`(````````&``````````@`````````$`````````#1
M`````0````,`````````<)T!``````!PG0```````)`"````````````````
M```(``````````@`````````U@````$````#``````````"@`0```````*``
M``````"`````````````````````"````````````````````-P````(````
M`P````````"`H`$``````("@````````*!````````````````````@`````
M``````````````#A`````0```#````````````````````"`H````````"8`
M```````````````````!``````````$``````````0````,`````````````
M````````````IJ````````#J`````````````````````0``````````````
$````````
